=================================================
Orthogonal distance regression (:mod:`scipy.odr`)
=================================================

.. automodule:: scipy.odr

.. autoclass:: Data

   .. automethod:: set_meta

.. autoclass:: Model

   .. automethod:: set_meta

.. autoclass:: ODR

   .. automethod:: restart

   .. automethod:: run

   .. automethod:: set_iprint

   .. automethod:: set_job

.. autoclass:: Output

   .. automethod:: pprint

.. autoexception:: odr_error

.. autoexception:: odr_stop

.. autofunction:: odr
